/**** simulate the effects of immigration on wages using the data 1990-2006
we simulate using random distribution of parameters****/

** import and merge the files with wage and hours worked ***
clear
cd C:\simulations  
set mem 300M 
set matsize 800

use supply_groups_60_06_specification_1.dta
sort year edu exp
save employment, replace
clear
use supply_wage_60_06_specification_1
sort year edu exp
merge year edu exp using employment

** keep only 1990 and 2006
drop if year<1990
drop if year==2000

** define the new broad and fine education indices
** broad 1 for HS or less and broad=2 for some college or more
** fine is now a sub-index going from 1 to 2 and defines the low and hig education subgroup in each broad group.

gen broad=1 if edu<3
replace broad=2 if edu>=3

gen fine=1 if edu==1|edu==3
replace fine=2 if edu==2|edu==4


*generate hours worked and wages by group
gen howo_for=howo_ma_for+howo_fe_for
gen howo_us=howo_ma_us+howo_fe_us

gen weekly_for=(howo_ma_for*weekly_ma_for+howo_fe_for*weekly_fe_for)/(howo_ma_for+howo_fe_for)
gen weekly_us=(howo_ma_us*weekly_ma_us+howo_fe_us*weekly_fe_us)/(howo_ma_us+howo_fe_us)

sort broad fine exp year

*** create wage shares in 1990 and 2006

egen wagebill_us=sum(howo_us*weekly_us), by(year)
egen wagebill_for=sum(howo_for*weekly_for), by(year)
gen share_wage_us=(howo_us*weekly_us)/(wagebill_us+wagebill_for)
gen share_wage_for=(howo_for*weekly_for)/(wagebill_us+wagebill_for)


* percentage increases in the group of foreign-born, 1990-2006 *
gen dperc_for_90_06=(howo_for[_n+1]-howo_for)/howo_for if year==1990
gen dperc_for_90_06_oftotal=(howo_for[_n+1]-howo_for)/(howo_for+howo_us) if year==1990
gen dweekly_us_90_06=(weekly_us[_n+1]-weekly_us)/weekly_us
drop if year==2006

** now we have a cross section

****  complementarity effect from immigration in all groups
egen effect1_90_06=sum(share_wage_for*dperc_for_90_06)

sort broad
****  complementarity effect from immigration in groups with same broad education
egen effect2_90_06=sum(share_wage_for*dperc_for_90_06), by(broad)

sort edu
***substitution effect from group with same broad and fine education 
egen effect3_90_06=sum(share_wage_for*dperc_for_90_06), by(edu)

***substitution effect from group with same broad and fine education and experience
gen effect4_90_06=share_wage_for*dperc_for_90_06

*** share in wage of group with same education
gen share_wage_ksjt=share_wage_for+ share_wage_us
sort broad
egen share_wage_kt=sum(share_wage_ksjt), by (broad)
sort edu
egen share_wage_kst=sum(share_wage_ksjt), by (edu)
save temp1, replace

*** combining all effects, into effect on US born and foreign-born wages
*** parameters, allowing different elast between some HS-HSG and someCO-COG, asn also different sigma_immi in H and L


clear
set more off
forvalues i = 1(1)1000 {
/**Open file with all the vars */
use temp1


/** generate a bunch of parameters from estimated averages and standard deviations
take the average estimate from the desired specificaiotn
take the standard eror and multiply it by suqre root of 32 (as this is the way I construct the random var)**/

/* this is specification 8 in the table 6 */
gen inv_s_HL=rnormal(0.71, 0.8475)

gen inv_s_L=rnormal(0.0, 0.001)

gen inv_s_H=rnormal(0.0, 0.001)

gen inv_s_exp=rnormal(0.16, 0.282)

gen inv_s_immi_H=rnormal(0.03, 0.169)

gen inv_s_immi_L=rnormal(0.09, 0.0565)


****generate the series with all the same parameter, averaging those ***
egen inv_sigma_HL=mean(inv_s_HL)
egen inv_sigma_sub_L=mean(inv_s_L)
egen inv_sigma_sub_H=mean(inv_s_H)
egen inv_sigma_exp=mean(inv_s_exp)
egen inv_sigma_immi_L=mean(inv_s_immi_L)
egen inv_sigma_immi_H=mean(inv_s_immi_H)

gen round=`i'

gen dperc_wage_us_90_06=(inv_sigma_HL)*(effect1_90_06)+((inv_sigma_sub_L)*(broad==1)+(inv_sigma_sub_H)*(broad==2) -(inv_sigma_HL))*(1/share_wage_kt)*(effect2_90_06)+((inv_sigma_exp)-(inv_sigma_sub_L)*(broad==1)-(inv_sigma_sub_H)*(broad==2))*(1/share_wage_kst)*(effect3_90_06)+((inv_sigma_immi_L)*(broad==1)+(inv_sigma_immi_H)*(broad==2)-(inv_sigma_exp))*(1/share_wage_ksjt)*(effect4_90_06)
gen dperc_wage_for_90_06=(inv_sigma_HL)*(effect1_90_06)+((inv_sigma_sub_L)*(broad==1)+(inv_sigma_sub_H)*(broad==2) -(inv_sigma_HL))*(1/share_wage_kt)*(effect2_90_06)+((inv_sigma_exp)-(inv_sigma_sub_L)*(broad==1)-(inv_sigma_sub_H)*(broad==2))*(1/share_wage_kst)*(effect3_90_06)+((inv_sigma_immi_L)*(broad==1)+(inv_sigma_immi_H)*(broad==2)-(inv_sigma_exp))*(1/share_wage_ksjt)*(effect4_90_06)-((inv_sigma_immi_L)*(broad==1)+(inv_sigma_immi_H)*(broad==2))*(dperc_for_90_06)

/** collect the results **/
keep round edu exp dperc_wage_us_90_06 dperc_wage_for_90_06 


/** If it is NOT the first pass (i=1), then save and append. Otherwise, just save **/
if (`i'!=1) {
save simulated`i', replace
append using simulated_all
}


save simulated_all, replace
clear
}


/** The final part here is just deleting all the temporary files **/
forvalues x=2(1)1000 {
rm simulated`x'.dta
}

use simulated_all
sort edu exp
collapse (mean) d_wage_us=dperc_wage_us_90_06 d_wage_for=dperc_wage_for_90_06 (sd) sd_us=dperc_wage_us_90_06  sd_for=dperc_wage_for_90_06, by (edu exp)

save simulated_changes.dta, replace
rm simulated_all.dta



 













